@@ -1,12 +1,13 @@
 "year.strict" <- function(...)
-  stop("you must expand 2-digit year abbreviations")
+    stop("you must expand 2-digit year abbreviations")
 
 "year.expand" <-
-function(y, cut.off = 30, century = c(1900, 2000), ...) {
+function(y, cut.off = 30, century = c(1900, 2000), ...)
+{
     ## cut.off specifies year for rounding up/down
     if(!is.numeric(y))
         stop("must be a numeric year specification")
-    i <- (y >= 0 & y <= 99)
+    i <- (!is.na(y) & (y >= 0) & (y <= 99))
     if(any(i))
         y[i] <- ifelse(y[i] < cut.off,
                        y[i] + century[2],
